@@ -118,6 +118,24 @@ def test_correct_single(comm):
 
     assert_array_equal(correct, buffer2.view_output())
 
+@MPITest(1)
+def test_plan_backward(comm):
+    procmesh = pfft.ProcMesh(np=[1], comm=comm)
+
+    partition = pfft.Partition(pfft.Type.PFFT_R2C, [2, 2],
+        procmesh, flags=pfft.Flags.PFFT_ESTIMATE | pfft.Flags.PFFT_TRANSPOSED_OUT)
+
+    buffer1 = pfft.LocalBuffer(partition)
+    buffer2 = pfft.LocalBuffer(partition)
+
+    plan = pfft.Plan(partition, pfft.Direction.PFFT_FORWARD, buffer1, buffer2)
+    assert plan.flags & pfft.Flags.PFFT_TRANSPOSED_OUT
+    assert plan.type == pfft.Type.PFFT_R2C
+
+    plan = pfft.Plan(partition, pfft.Direction.PFFT_BACKWARD, buffer1, buffer2)
+    assert plan.flags & pfft.Flags.PFFT_TRANSPOSED_IN
+    assert plan.type == pfft.Type.PFFT_C2R
+
 @MPITest(1)
 def test_raw(comm):
     procmesh = pfft.ProcMesh(np=[1], comm=comm)
@@ -292,3 +310,35 @@ def test_2d_on_2d_r2c(comm):
     result[partition.local_o_slice] = buffer2.view_output()
     result = comm.allreduce(result)
     assert_almost_equal(correct, result)
+
+@MPITest(1)
+def test_1d(comm):
+    procmesh = pfft.ProcMesh(np=[], comm=comm)
+
+    N = (16)
+
+    data = numpy.arange(numpy.prod(N), dtype='f8').reshape(N)
+
+    correct = numpy.fft.rfftn(data.copy())
+    result = numpy.zeros_like(correct)
+
+    partition = pfft.Partition(pfft.Type.PFFT_R2C,
+            [16], procmesh,
+            pfft.Flags.PFFT_TRANSPOSED_OUT |
+            pfft.Flags.PFFT_PADDED_R2C
+    )
+
+    assert_array_equal(partition.i_edges[0], [0, 16])
+
+    # 1d-transforms are not supported by pfft.
+    #buffer1 = pfft.LocalBuffer(partition)
+    #buffer2 = pfft.LocalBuffer(partition)
+
+    #buffer1.view_input()[:] = data[partition.local_i_slice]
+
+    #plan = pfft.Plan(partition, pfft.Direction.PFFT_FORWARD, buffer1, buffer2)
+    #plan.execute(buffer1, buffer2)
+
+    #result[partition.local_o_slice] = buffer2.view_output()
+    #result = comm.allreduce(result)
+    #assert_almost_equal(correct, result)
